searchData={"items":[{"type":"module","title":"Deepl","doc":"An Elixir package providing a convenient interface to the [DeepL](https://www.deepl.com) API.","ref":"Deepl.html"},{"type":"function","title":"Deepl.base_url!/0","doc":"Get the base URL for the DeepL API based on the current plan.\n\nReturns the base URL for the DeepL API, which varies depending on whether the user has a\nfree or pro plan.","ref":"Deepl.html#base_url!/0"},{"type":"function","title":"Examples - Deepl.base_url!/0","doc":"iex> Deepl.base_url!()\n    \"https://api-free.deepl.com\"","ref":"Deepl.html#base_url!/0-examples"},{"type":"function","title":"Deepl.get_api_key/0","doc":"Get the API key from the application environment.\n\nRetrieves the API key set in the application configuration.","ref":"Deepl.html#get_api_key/0"},{"type":"function","title":"Examples - Deepl.get_api_key/0","doc":"iex> Deepl.get_api_key()\n    \"wwwwwwww-xxxx-yyyy-zzzz-123456789012:fx\"","ref":"Deepl.html#get_api_key/0-examples"},{"type":"function","title":"Deepl.plan!/0","doc":"Gets the current plan of the DeepL API based on the API key.\n\nReturns `:free` for free accounts and `:pro` for pro accounts.","ref":"Deepl.html#plan!/0"},{"type":"function","title":"Examples - Deepl.plan!/0","doc":"iex> Deepl.plan!()\n    :free","ref":"Deepl.html#plan!/0-examples"},{"type":"function","title":"Deepl.set_api_key/1","doc":"Sets the API key for the DeepL service.\n\nStores the API key string in the application environment.","ref":"Deepl.html#set_api_key/1"},{"type":"function","title":"Examples - Deepl.set_api_key/1","doc":"iex> Deepl.set_api_key(\"wwwwwwww-xxxx-yyyy-zzzz-123456789012:fx\")\n    :ok","ref":"Deepl.html#set_api_key/1-examples"},{"type":"module","title":"Deepl.Text","doc":"Module for translating text using the DeepL API.","ref":"Deepl.Text.html"},{"type":"type","title":"Deepl.Text.text/0","doc":"","ref":"Deepl.Text.html#t:text/0"},{"type":"function","title":"Deepl.Text.translate/3","doc":"Translates a single or multiple texts to the specified target language.\n\nThe `text` parameter can be a single string or a list of strings.","ref":"Deepl.Text.html#translate/3"},{"type":"function","title":"Examples - Deepl.Text.translate/3","doc":"iex> Deepl.Text.translate(\"Hello World\", \"ID\")\n    %{\n      \"translations\" => [\n        %{\"detected_source_language\" => \"EN\", \"text\" => \"Halo Dunia\"}\n      ]\n    }}\n\n    iex> Deepl.Text.translate([\"Hello World\", \"Hello Developer\"], \"ID\")\n    {:ok,\n    %{\n      \"translations\" => [\n        %{\"detected_source_language\" => \"EN\", \"text\" => \"Halo Dunia\"},\n        %{\"detected_source_language\" => \"EN\", \"text\" => \"Halo Pengembang\"}\n      ]\n    }}\n\n    iex> Deepl.Text.translate(\"Hello World\", \"ID\", show_billed_characters: true)\n    {:ok,\n    %{\n      \"translations\" => [\n        %{\n          \"billed_characters\" => 11,\n          \"detected_source_language\" => \"EN\",\n          \"text\" => \"Halo Dunia\"\n        }\n      ]\n    }}","ref":"Deepl.Text.html#translate/3-examples"},{"type":"function","title":"Deepl.Text.translate!/3","doc":"Translates a single or multiple texts to the specified target language.\n\nThis function like `translate/3`, but raises an error if the translation fails.","ref":"Deepl.Text.html#translate!/3"},{"type":"module","title":"Deepl.Usage","doc":"Module for retrieving usage and quota for the current billing period with the DeepL API.\n\nFor more information, refer to the retrieve usage and quota\n[documentation](https://developers.deepl.com/api-reference/usage-and-quota).","ref":"Deepl.Usage.html"},{"type":"function","title":"Deepl.Usage.get/0","doc":"Retrieve current usage and quota information.","ref":"Deepl.Usage.html#get/0"},{"type":"function","title":"Examples - Deepl.Usage.get/0","doc":"iex> Deepl.Usage.get()\n    %{\"character_count\": 100, \"character_limit\": 500000}","ref":"Deepl.Usage.html#get/0-examples"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"0.0.1 (2025-07-19) - Changelog","doc":"","ref":"changelog.html#0-0-1-2025-07-19"},{"type":"extras","title":"Getting Started","doc":"# Getting Started\n\n[![Hex.pm](https://img.shields.io/hexpm/v/deepl)](https://hex.pm/packages/deepl)\n[![Hex.pm Downloads](https://img.shields.io/hexpm/dt/deepl)](https://hex.pm/packages/deepl)\n\nThe [DeepL API](https://www.deepl.com/docs-api) provides a way for programs to send texts and\ndocuments to DeepL's servers and receive high-quality translations and text improvements. This\nenables developers to build a wide range of translation tools using DeepL's leading translation technology.\n\n`deepl` is a **community-maintained** Elixir package for integrating with the DeepL API.","ref":"getting-started.html"},{"type":"extras","title":"Requirements - Getting Started","doc":"To use `deepl`, your environment must meet these requirements:\n\n- **Erlang**: Version `27.0` or later\n- **Elixir**: Version `1.18.0-otp-27` or later","ref":"getting-started.html#requirements"},{"type":"extras","title":"Installation - Getting Started","doc":"Add `deepl` to the dependencies in your `mix.exs` file:\n\n```elixir\ndef deps do\n  [\n    {:deepl, \"~> 0.1.2\"}\n  ]\nend\n```\n\nFetch the dependencies by running:\n\n```sh\nmix deps.get\n```","ref":"getting-started.html#installation"},{"type":"extras","title":"Authentication - Getting Started","doc":"To use the API, you need an authentication key, which you can find in the\n[API Keys section](https://www.deepl.com/en/your-account/keys) of your DeepL account. You can translate up to 500,000 characters per month for free.\n\nSet the key in your config:\n\n```elixir\n# config/config.exs\nconfig :deepl, api_key: \"your-api-key\"\n```\n\nAlternatively, set it at runtime:\n\n```elixir\niex> Deepl.set_api_key(\"your-api-key\")\n:ok\n```","ref":"getting-started.html#authentication"},{"type":"extras","title":"Usage - Getting Started","doc":"Translate a text:\n\n```elixir\niex> Deepl.Text.translate(\"Hello World\", \"ID\")\n{:ok,\n %{\n   \"translations\" => [\n     %{\"detected_source_language\" => \"EN\", \"text\" => \"Halo Dunia\"}\n   ]\n }}\n\niex> Deepl.Text.translate([\"Hello World\", \"Hello Developer\"], \"ID\")\n{:ok,\n %{\n   \"translations\" => [\n     %{\"detected_source_language\" => \"EN\", \"text\" => \"Halo Dunia\"},\n     %{\"detected_source_language\" => \"EN\", \"text\" => \"Halo Pengembang\"}\n   ]\n }}\n\niex> Deepl.Text.translate(\"Hello World\", \"ID\", show_billed_characters: true)\n{:ok,\n %{\n   \"translations\" => [\n     %{\n       \"billed_characters\" => 11,\n       \"detected_source_language\" => \"EN\",\n       \"text\" => \"Halo Dunia\"\n     }\n   ]\n }}\n```","ref":"getting-started.html#usage"},{"type":"extras","title":"License - Getting Started","doc":"This package is licensed under the [MIT License](https://github.com/muzhawir/deepl/blob/main/LICENSE.md).","ref":"getting-started.html#license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}